summaryrefslogtreecommitdiffstats
path: root/kreversi/kreversi.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:46 -0600
commit58a97ed3af5e4df6c4a58d043b0c267bd97056a9 (patch)
tree5a2fde6842fd422cae2d8670d382be965098cc32 /kreversi/kreversi.cpp
parent2ce15ee76fd2d9d18a63c035a0f5b00b94c60cdc (diff)
downloadtdegames-58a97ed3af5e4df6c4a58d043b0c267bd97056a9.tar.gz
tdegames-58a97ed3af5e4df6c4a58d043b0c267bd97056a9.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kreversi/kreversi.cpp')
-rw-r--r--kreversi/kreversi.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kreversi/kreversi.cpp b/kreversi/kreversi.cpp
index c3a047e3..5132d730 100644
--- a/kreversi/kreversi.cpp
+++ b/kreversi/kreversi.cpp
@@ -108,7 +108,7 @@ KReversi::KReversi()
top->addMultiCellWidget(m_gameView, 0, 1, 0, 0);
// Populate the GUI.
- createKActions();
+ createTDEActions();
addWidget(m_gameView);
// Connect the signals from the game with slots of the view
@@ -144,10 +144,10 @@ KReversi::~KReversi()
// Create all KActions used in KReversi.
//
-void KReversi::createKActions()
+void KReversi::createTDEActions()
{
// Standard Game Actions.
KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(slotNewGame()), actionCollection(),
@@ -161,13 +161,13 @@ void KReversi::createKActions()
"game_undo");
// Non-standard Game Actions: Stop, Continue, Switch sides
- stopAction = new KAction(i18n("&Stop Thinking"), "game_stop", TQt::Key_Escape,
+ stopAction = new TDEAction(i18n("&Stop Thinking"), "game_stop", TQt::Key_Escape,
TQT_TQOBJECT(this), TQT_SLOT(slotInterrupt()), actionCollection(),
"game_stop");
- continueAction = new KAction(i18n("&Continue Thinking"), "reload", 0,
+ continueAction = new TDEAction(i18n("&Continue Thinking"), "reload", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotContinue()), actionCollection(),
"game_continue");
- new KAction(i18n("S&witch Sides"), 0, 0,
+ new TDEAction(i18n("S&witch Sides"), 0, 0,
TQT_TQOBJECT(this), TQT_SLOT(slotSwitchSides()), actionCollection(),
"game_switch_sides");
@@ -176,11 +176,11 @@ void KReversi::createKActions()
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotEditSettings()), actionCollection());
// Actions for the view(s).
- showLastMoveAction = new KToggleAction(i18n("Show Last Move"), "lastmoves", 0,
+ showLastMoveAction = new TDEToggleAction(i18n("Show Last Move"), "lastmoves", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotShowLastMove()),
actionCollection(),
"show_last_move");
- showLegalMovesAction = new KToggleAction(i18n("Show Legal Moves"), "legalmoves", 0,
+ showLegalMovesAction = new TDEToggleAction(i18n("Show Legal Moves"), "legalmoves", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotShowLegalMoves()),
actionCollection(),
"show_legal_moves");
@@ -209,7 +209,7 @@ void KReversi::setStrength(uint strength)
// ----------------------------------------------------------------
// Slots for KActions
// A slot that is called when the user wants a new game.
@@ -144,10 +144,10 @@ KReversi::~KReversi()
// Connect the signals from the game with slots of the view
-// Create all KActions used in KReversi.
+// Create all TDEActions used in KReversi.
//
@@ -209,7 +209,7 @@ void KReversi::setStrength(uint strength)
// ----------------------------------------------------------------
-// Slots for KActions
+// Slots for TDEActions
// A slot that is called when the user wants a new game.